from typing import Optional
from pydantic import BaseModel, ConfigDict


class Metadata(BaseModel):
    title: Optional[str] = None
    fullDescription: Optional[str] = None
    framework: Optional[str] = None
    licence: Optional[str] = None
    avgRunTimeSeconds: Optional[float] = None
    avgRunTokens: Optional[float] = None
    tags: Optional[list[str]] = None
    ui: Optional[str] = None

    model_config = ConfigDict(extra="allow")



from typing import Annotated, Literal, Union
from pydantic import BaseModel, Discriminator, Field


class UserMessage(BaseModel):
    role: Literal['user']
    content: str


class AssistantMessage(BaseModel):
    role: Literal['assistant']
    content: str


Message = Annotated[Union[UserMessage, AssistantMessage], Discriminator('role')]


class MessageInput(BaseModel):
    messages: list[Message]


class MessageOutput(BaseModel):
    messages: list[Message]



import logging
import os

from opentelemetry import trace
from opentelemetry.sdk.resources import Resource, SERVICE_NAME, SERVICE_VERSION
from opentelemetry.sdk.trace import TracerProvider
from opentelemetry.sdk.trace.export import (
    BatchSpanProcessor, SpanExportResult
)
from opentelemetry.exporter.otlp.proto.http.trace_exporter import OTLPSpanExporter
from mcp.server.fastmcp import FastMCP


class SilentOTLPSpanExporter(OTLPSpanExporter):
    def export(self, spans):
        try:
            return super().export(spans)
        except Exception as e:
            logging.debug(f"OpenTelemetry Exporter failed silently: {e}")
            return SpanExportResult.FAILURE


async def run_agent_provider(server: FastMCP):
    server.settings.port = int(os.getenv("PORT", "8000"))
    trace.set_tracer_provider(
        tracer_provider=TracerProvider(
            resource=Resource(attributes={
                SERVICE_NAME: server.name
            }),
            active_span_processor=BatchSpanProcessor(SilentOTLPSpanExporter())
        )
    )
    with trace.get_tracer('beeai-sdk').start_as_current_span("agent-provider"):
        try:
            await server.run_sse_async()
        except KeyboardInterrupt:
            pass


from typing import Any
from pydantic import BaseModel


class Config(BaseModel):
    """Base class for configuration models, enforces flat structure with string values"""

    @classmethod
    def __pydantic_init_subclass__(cls, **kwargs: Any) -> None:
        super().__pydantic_init_subclass__(**kwargs)
        for field_name, field_info in cls.model_fields.items():
            if field_info.annotation is not str:
                raise ValueError(f"Type {field_info.annotation} of field {field_name} is not allowed.")
